==> vue-components-1.5.13.tgz: package/lib/ui/radios/src/DescriptionRadioPanelList.vue.rd.js <==
import { useVModel as p } from "@vueuse/core";
import { defineComponent as m, openBlock as a, createElementBlock as l, createElementVNode as s, toDisplayString as d, createVNode as i, unref as r, withCtx as b, Fragment as f, renderList as k, normalizeClass as n, renderSlot as v } from "vue";
import { RAntRadioButtonGroup as y, RAntRadioButton as _ } from "../../../form/index.rd.js";
import { descriptionCardListRadioProps as x } from "./props.rd.js";
const h = { class: "w-full" }, g = { class: "sr-only" }, C = { class: "bg-white border-slate-300 border-solid border-1 dark:bg-slate-900 dark:border-slate-700 rounded-md -space-y-px" }, R = ["onClick"], w = {
  key: 0,
  class: "ml-3 flex flex-col"
}, N = /* @__PURE__ */ m({
  __name: "DescriptionRadioPanelList",
  props: x(),
  emits: ["update:value"],
  setup(u, { emit: B }) {
    const t = p(u, "value");
    function c(o) {
      t.value = o;
    }
    return (o, V) => (a(), l("fieldset", h, [
      s("legend", g, d(o.title), 1),
      i(r(y), {
        value: r(t),
        class: "w-full"
      }, {
        default: b(() => [
          s("div", C, [
            (a(!0), l(f, null, k(o.items, (e) => (a(), l("label", {
              key: e.value,
              class: n([{
                "bg-primary-50 !border-primary-200  dark:!border-primary-400 dark:bg-primary-900 dark:bg-opacity-30 z-10": r(t) == e.value
              }, "border-gray-200 dark:border-slate-700 border-solid border-1 first:rounded-tl-md first:rounded-tr-md last:rounded-bl-md last:rounded-br-md relative border p-4 flex cursor-pointer focus:outline-none"]),
              onClick: () => c(e.value)
            }, [
              i(r(_), {
                value: e.value,
                checked: e.value == r(t)
              }, null, 8, ["value", "checked"]),
              o.$slots.customContent ? v(o.$slots, "customContent", {
                key: 1,
                item: e,
                selected: e.value == r(t)
              }) : (a(), l("div", w, [
                s("span", {
                  class: n([{
                    "dark:text-primary-500 text-primary-900": r(t) == e.value
                  }, "dark:text-white block text-sm font-bold"])
                }, d(e.text), 3),
                s("span", {
                  class: n([{
                    "dark:text-primary-400 text-primary-700": r(t) == e.value
                  }, "block text-muted text-sm"])
                }, d(e.description), 3)
              ]))
            ], 10, R))), 128))
          ])
        ]),
        _: 3
      }, 8, ["value"])
    ]));
  }
});
export {
  N as default
};

==> vue-components-1.6.3.tgz: package/lib/ui/radios/src/DescriptionRadioPanelList.vue.rd.js <==
import { defineComponent as p, openBlock as a, createElementBlock as l, createElementVNode as s, toDisplayString as d, createVNode as i, unref as r, withCtx as m, Fragment as b, renderList as f, normalizeClass as n, renderSlot as k } from "vue";
import { useVModel as v } from "@vueuse/core";
import { RAntRadioButtonGroup as y, RAntRadioButton as _ } from "../../../form/index.rd.js";
import { descriptionCardListRadioProps as x } from "./props.rd.js";
const h = { class: "w-full" }, g = { class: "sr-only" }, C = { class: "bg-white border-slate-300 border-solid border-1 dark:bg-slate-900 dark:border-slate-700 rounded-md -space-y-px" }, R = ["onClick"], w = {
  key: 0,
  class: "ml-3 flex flex-col"
}, N = /* @__PURE__ */ p({
  __name: "DescriptionRadioPanelList",
  props: x(),
  emits: ["update:value"],
  setup(u, { emit: B }) {
    const t = v(u, "value");
    function c(o) {
      t.value = o;
    }
    return (o, V) => (a(), l("fieldset", h, [
      s("legend", g, d(o.title), 1),
      i(r(y), {
        value: r(t),
        class: "w-full"
      }, {
        default: m(() => [
          s("div", C, [
            (a(!0), l(b, null, f(o.items, (e) => (a(), l("label", {
              key: e.value,
              class: n([{
                "bg-primary-50 !border-primary-200  dark:!border-primary-400 dark:bg-primary-900 dark:bg-opacity-30 z-10": r(t) == e.value
              }, "border-gray-200 dark:border-slate-700 border-solid border-1 first:rounded-tl-md first:rounded-tr-md last:rounded-bl-md last:rounded-br-md relative border p-4 flex cursor-pointer focus:outline-none"]),
              onClick: () => c(e.value)
            }, [
              i(r(_), {
                value: e.value,
                checked: e.value == r(t)
              }, null, 8, ["value", "checked"]),
              o.$slots.customContent ? k(o.$slots, "customContent", {
                key: 1,
                item: e,
                selected: e.value == r(t)
              }) : (a(), l("div", w, [
                s("span", {
                  class: n([{
                    "dark:text-primary-500 text-primary-900": r(t) == e.value
                  }, "dark:text-white block text-sm font-bold"])
                }, d(e.text), 3),
                s("span", {
                  class: n([{
                    "dark:text-primary-400 text-primary-700": r(t) == e.value
                  }, "block text-muted text-sm"])
                }, d(e.description), 3)
              ]))
            ], 10, R))), 128))
          ])
        ]),
        _: 3
      }, 8, ["value"])
    ]));
  }
});
export {
  N as default
};
